# Rick Roll Package

A package that has a function to rick roll people

# Installation

``` npm i ricklolroll ```

# Usage
To rick roll someone , do ```rickroll()```

# Contact
[Contact the creator (me)](mailto:anas@hacktype.tk)